@@ -1,11 +1,11 @@
-//! API client for the [Mintscan] Cosmos explorer by [Cosmostation].
-//!
-//! [Mintscan]: https://www.mintscan.io/
-//! [Cosmostation]: https://www.cosmostation.io/
-
-#![doc(html_root_url = "https://docs.rs/mintscan/0.3.0")]
-#![forbid(unsafe_code, clippy::unwrap_used)]
-#![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
+#![doc = include_str!("../README.md")]
+#![forbid(unsafe_code)]
+#![warn(
+    clippy::unwrap_used,
+    missing_docs,
+    rust_2018_idioms,
+    unused_qualifications
+)]
 
 pub mod coin;
 pub mod v1;
@@ -35,9 +35,11 @@ impl Mintscan {
     /// Create a new Mintscan client for the given API hostname
     /// (e.g. `api.cosmostation.io`)
     pub fn new(hostname: impl Into<String>) -> Self {
-        Self {
-            client: HttpsClient::new(hostname),
-        }
+        let mut client = HttpsClient::new(hostname);
+        client
+            .add_header(iqhttp::header::REFERER, "https://mintscan.io/")
+            .expect("couldn't add referer header");
+        Self { client }
     }
 
     /// Get `/v1/status` endpoint.
